@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2012 by Volker Lanz <vl@fidra.de>                      *
+ *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -50,7 +51,8 @@ const std::array< QColor, FileSystem::__lastType > FileSystem::defaultColorCode
     QColor( 33,137,108 ),
     QColor( 250,230,255 ),
     QColor( 242,155,104 ),
-    QColor( 160,210,180 )
+    QColor( 160,210,180 ),
+    QColor( 255,170,0 )
 };
 
 
@@ -318,6 +320,7 @@ static const QString* typeNames()
         i18nc("@item filesystem name", "exfat"),
         i18nc("@item filesystem name", "nilfs2"),
         i18nc("@item filesystem name", "lvm2 pv"),
+        i18nc("@item filesystem name", "f2fs"),
     };
 
     return s;
